Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(272)

Unified Diff: webrtc/system_wrappers/source/event_timer_posix.h

Issue 1920043002: Replace scoped_ptr with unique_ptr in webrtc/base/ (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Rebased Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/pc/mediasession_unittest.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/system_wrappers/source/event_timer_posix.h
diff --git a/webrtc/system_wrappers/source/event_timer_posix.h b/webrtc/system_wrappers/source/event_timer_posix.h
index af3715ee8b222186672f24eb031f2eb3827acd0b..599eb55ee16a1d4f783667e1bfaab717c2f15f93 100644
--- a/webrtc/system_wrappers/source/event_timer_posix.h
+++ b/webrtc/system_wrappers/source/event_timer_posix.h
@@ -13,6 +13,8 @@
#include "webrtc/system_wrappers/include/event_wrapper.h"
+#include <memory>
+
#include <pthread.h>
#include <time.h>
@@ -49,9 +51,9 @@ class EventTimerPosix : public EventTimerWrapper {
pthread_mutex_t mutex_;
bool event_set_;
- // TODO(pbos): Remove scoped_ptr and use PlatformThread directly.
- rtc::scoped_ptr<rtc::PlatformThread> timer_thread_;
- rtc::scoped_ptr<EventTimerPosix> timer_event_;
+ // TODO(pbos): Remove unique_ptr and use PlatformThread directly.
+ std::unique_ptr<rtc::PlatformThread> timer_thread_;
+ std::unique_ptr<EventTimerPosix> timer_event_;
timespec created_at_;
bool periodic_;
« no previous file with comments | « webrtc/pc/mediasession_unittest.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698